package com.mysql.jdbc;

import java.security.MessageDigest;
import java.security.NoSuchAlgorithmException;

/* loaded from: com_mysql_jdbc.jar:com/mysql/jdbc/Security.class */
class Security {
    private static final char PVERSION41_CHAR = '*';
    private static final int SHA1_HASH_SIZE = 20;

    private static int charVal(char c) {
        return (c < '0' || c > '9') ? (c < 'A' || c > 'Z') ? (c - 'a') + 10 : (c - 'A') + 10 : c - '0';
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public static byte[] createKeyFromOldPassword(String passwd) throws NoSuchAlgorithmException {
        int[] salt = getSaltFromPassword(makeScrambledPassword(passwd));
        return getBinaryPassword(salt, false);
    }

    static byte[] getBinaryPassword(int[] salt, boolean usingNewPasswords) throws NoSuchAlgorithmException {
        byte[] binaryPassword = new byte[SHA1_HASH_SIZE];
        if (usingNewPasswords) {
            int pos = 0;
            for (int i = 0; i < 4; i++) {
                int val = salt[i];
                for (int t = 3; t >= 0; t--) {
                    int i2 = pos;
                    pos++;
                    binaryPassword[i2] = (byte) (val & 255);
                    val >>= 8;
                }
            }
            return binaryPassword;
        }
        int offset = 0;
        for (int i3 = 0; i3 < 2; i3++) {
            int val2 = salt[i3];
            for (int t2 = 3; t2 >= 0; t2--) {
                binaryPassword[t2 + offset] = (byte) (val2 % 256);
                val2 >>= 8;
            }
            offset += 4;
        }
        MessageDigest md = MessageDigest.getInstance("SHA-1");
        md.update(binaryPassword, 0, 8);
        return md.digest();
    }

    private static int[] getSaltFromPassword(String password) {
        int[] result = new int[6];
        if (password == null || password.length() == 0) {
            return result;
        }
        if (password.charAt(0) == PVERSION41_CHAR) {
            String saltInHex = password.substring(1, 5);
            int val = 0;
            for (int i = 0; i < 4; i++) {
                val = (val << 4) + charVal(saltInHex.charAt(i));
            }
            return result;
        }
        int resultPos = 0;
        int pos = 0;
        int length = password.length();
        while (pos < length) {
            int val2 = 0;
            for (int i2 = 0; i2 < 8; i2++) {
                int i3 = pos;
                pos++;
                val2 = (val2 << 4) + charVal(password.charAt(i3));
            }
            int i4 = resultPos;
            resultPos++;
            result[i4] = val2;
        }
        return result;
    }

    private static String longToHex(long val) {
        String longHex = Long.toHexString(val);
        int length = longHex.length();
        if (length < 8) {
            int padding = 8 - length;
            StringBuffer buf = new StringBuffer();
            for (int i = 0; i < padding; i++) {
                buf.append("0");
            }
            buf.append(longHex);
            return buf.toString();
        }
        return longHex.substring(0, 8);
    }

    static String makeScrambledPassword(String password) throws NoSuchAlgorithmException {
        long[] passwordHash = Util.newHash(password);
        StringBuffer scramble = new StringBuffer();
        scramble.append(longToHex(passwordHash[0]));
        scramble.append(longToHex(passwordHash[1]));
        return scramble.toString();
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public static void passwordCrypt(byte[] from, byte[] to, byte[] password, int length) {
        for (int pos = 0; pos < from.length && pos < length; pos++) {
            to[pos] = (byte) (from[pos] ^ password[pos]);
        }
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public static byte[] passwordHashStage1(String password) throws NoSuchAlgorithmException {
        MessageDigest md = MessageDigest.getInstance("SHA-1");
        StringBuffer cleansedPassword = new StringBuffer();
        int passwordLength = password.length();
        for (int i = 0; i < passwordLength; i++) {
            char c = password.charAt(i);
            if (c != ' ' && c != '\t') {
                cleansedPassword.append(c);
            }
        }
        return md.digest(cleansedPassword.toString().getBytes());
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public static byte[] passwordHashStage2(byte[] hashedPassword, byte[] salt) throws NoSuchAlgorithmException {
        MessageDigest md = MessageDigest.getInstance("SHA-1");
        md.update(salt, 0, 4);
        md.update(hashedPassword, 0, SHA1_HASH_SIZE);
        return md.digest();
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public static byte[] scramble411(String password, String seed) throws NoSuchAlgorithmException {
        MessageDigest md = MessageDigest.getInstance("SHA-1");
        byte[] passwordHashStage1 = md.digest(password.getBytes());
        md.reset();
        byte[] passwordHashStage2 = md.digest(passwordHashStage1);
        md.reset();
        byte[] seedAsBytes = seed.getBytes();
        md.update(seedAsBytes);
        md.update(passwordHashStage2);
        byte[] toBeXord = md.digest();
        int numToXor = toBeXord.length;
        for (int i = 0; i < numToXor; i++) {
            toBeXord[i] = (byte) (toBeXord[i] ^ passwordHashStage1[i]);
        }
        return toBeXord;
    }

    private Security() {
    }
}
